Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(175)

Unified Diff: pydir/crosstest.py

Issue 944333002: Subzero: Update tests and build scripts for sandboxing. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: More code review changes Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pydir/build-runtime.py ('k') | pydir/szbuild.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pydir/crosstest.py
diff --git a/pydir/crosstest.py b/pydir/crosstest.py
index 2faff705f07bb964ed8b48e3f2e967c6ddee6524..ffa78c08086765f017152c7bef41add494b40547 100755
--- a/pydir/crosstest.py
+++ b/pydir/crosstest.py
@@ -24,8 +24,8 @@ if __name__ == '__main__':
that calls the test functions with a variety of interesting inputs
and compares their results.
"""
- # arch_map maps a Subzero target string to an llvm-mc -arch string.
- arch_map = { 'x8632':'x86', 'x8664':'x86-64', 'arm':'arm' }
+ # arch_map maps a Subzero target string to an llvm-mc -triple string.
+ arch_map = { 'x8632':'i686', 'x8664':'x86_64', 'arm':'armv7a' }
desc = 'Build a cross-test that compares Subzero and llc translation.'
argparser = argparse.ArgumentParser(description=desc)
argparser.add_argument('--test', required=True, action='append',
@@ -113,7 +113,7 @@ if __name__ == '__main__':
bitcode])
if args.filetype != 'obj':
shellcmd(['llvm-mc',
- '-arch=' + arch_map[args.target],
+ '-triple=' + arch_map[args.target],
'-filetype=obj',
'-o=' + obj_sz,
asm_sz])
@@ -144,12 +144,9 @@ if __name__ == '__main__':
else:
objs.append(bitcode)
- # Use 'clang szrt.c' -or- 'clang++ szrt.cpp'
objs.append((
- '{root}/toolchain_build/src/subzero/runtime/szrt.{ext}'
- ).format(root=nacl_root, ext='c' if pure_c else 'cpp'))
- objs.append((
- '{root}/toolchain_build/src/subzero/runtime/szrt_i686.ll'
+ '{root}/toolchain_build/src/subzero/build/runtime/' +
+ 'szrt_native_x8632.o'
).format(root=nacl_root))
linker = 'clang' if pure_c else 'clang++'
shellcmd([linker, '-g', '-m32', args.driver] +
« no previous file with comments | « pydir/build-runtime.py ('k') | pydir/szbuild.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698